@@ -16,12 +16,10 @@
  */
 package org.apache.commons.logging;
 
+public class LogTestCase extends AbstractLogTest {
 
-public class LogTestCase extends AbstractLogTest
-{
-
-    public Log getLogObject()
-    {
+    @Override
+    public Log getLogObject() {
         /**
          * Pickup whatever is found/configured!
          */
