@@ -17,16 +17,41 @@
 
 package org.apache.commons.logging.tccl.custom;
 
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 public class MyLogFactoryImpl extends LogFactory {
-    public Object getAttribute(String name) { return null; }
-    public String[] getAttributeNames() { return null; }
-    public Log getInstance(Class clazz) { return null; }
-    public Log getInstance(String name) { return null; }
-    public void release() {}
-    public void removeAttribute(String name) {}
-    public void setAttribute(String name, Object value) {}
+
+    @Override
+    public Object getAttribute(final String name) {
+        return null;
+    }
+
+    @Override
+    public String[] getAttributeNames() {
+        return null;
+    }
+
+    @Override
+    public Log getInstance(final Class<?> clazz) {
+        return null;
+    }
+
+    @Override
+    public Log getInstance(final String name) {
+        return null;
+    }
+
+    @Override
+    public void release() {
+    }
+
+    @Override
+    public void removeAttribute(final String name) {
+    }
+
+    @Override
+    public void setAttribute(final String name, final Object value) {
+    }
+
 }
